import os
import sys
import ROOT as R
import pandas as pd
import numpy as np
import pickle
import json
import tabulate
import yaml
import itertools
from pathlib import Path


# local imports.
#%load_ext autoreload
##%autoreload 2
#sys.path.append("/home/belle2/vikasraj/b2kpi/ri_my/belle/utils")

#import fit_utils_2 as fu
#from useful_funcs import read_yaml

# silence annoying roofit messages
#fu.silence_root()

# enable multithreading
R.ROOT.EnableImplicitMT(10)

# Open the workspace from the ROOT file
f = R.TFile.Open("sample.root")
ws = f.Get("dt_workspace")  # Assuming the workspace is called 'dt_workspace'
ws.Print()

var = ws.var("deltat")
datasets = [ws.data("data_set_td_btag"), ws.data("data_set_td_bartag")]
pdfs = [ws.pdf("pdf_full_td_btag"), ws.pdf("pdf_full_td_bartag")]
cond_vars = [ws.var("deltaterr"), ws.var("r"), ws.var("mod_mbc"), ws.var("csobdtprime"), ws.var("deltae")]
nbins = 40
xrange = (var.getMin(), var.getMax())

# Set range
var.setRange("subrange", *xrange)

# Create frame
frame = var.frame()


# Plot B0 tag (index 0)
datasets[0].plotOn(frame, R.RooFit.Binning(nbins), R.RooFit.MarkerColor(R.kRed))
pdfs[0].plotOn(frame, R.RooFit.ProjWData(R.RooArgSet(*cond_vars), datasets[0]), R.RooFit.LineColor(R.kRed))

# Plot B0bar tag (index 1)
datasets[1].plotOn(frame, R.RooFit.Binning(nbins), R.RooFit.MarkerColor(R.kBlue))
pdfs[1].plotOn(frame, R.RooFit.ProjWData(R.RooArgSet(*cond_vars), datasets[1]), R.RooFit.LineColor(R.kBlue))

# Draw and save
c = R.TCanvas()
frame.Draw()
c.SaveAs("tagged_plot.png")
